import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 4
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


# absorption and PL data
solution_abs = pd.read_csv(os.path.join('data', 'Rub_solution_abs.csv'), header=0, index_col=0)
solid_abs = pd.read_csv(os.path.join('data', 'Rub_solid_abs.csv'), header=0, index_col=0)
np_pl = pd.read_csv(os.path.join('data', 'Rub_NP_PL.csv'), header=0, index_col=0)/1e4
np_pl_dbp = pd.read_csv(os.path.join('data', 'RubDBP_NP_PL.csv'), header=0, index_col=0)/1e4
solution_abs = solution_abs[solution_abs.index >= 360]
solid_abs = solid_abs[solid_abs.index >= 360]

fig, ax = plt.subplots(figsize=(0.8*0.47*14, 4))
#fig, ax = plt.subplots()

ax.plot(solution_abs.index, 10*solution_abs, linewidth=lw, color='0.5', linestyle='--', label=r'solution $\times$10')
#ax.plot(solid_abs.index, solid_abs['film']/solid_abs['film'].max(), linewidth=lw, color='forestgreen', linestyle='-.', label='film')
ax.plot(solid_abs.index, solid_abs['NP'], linewidth=lw, color='black', label='Rub NP')

ax2 = ax.twinx()

baseline = np_pl[np_pl.index < 515].mean()
y = 20*(np_pl-baseline)
ax2.plot(y.index, y, linewidth=lw, color=colour_rubrene, label=r'Rub NP PL $\times$20')
ax2.fill_between(y.index.values, np.squeeze(y.values), linewidth=0, color=colour_rubrene, alpha=0.15)

baseline = np_pl_dbp[np_pl_dbp.index < 515].mean()
y = (np_pl_dbp-baseline)
ax2.plot(y.index, y, linewidth=lw, color=colour_dbp, label='Rub/DBP NP PL')
#ax2.fill_between(y.index.values, np.squeeze(y.values), linewidth=0, color=colour_dbp, alpha=0.15)

ax.set_ylim(0, 1.1)
ax2.set_ylim(0, 15.5)
ax.set_xlim(360, 750)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
ax2 = uf.format_axes(ax2, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=0.2, yminorsep=0.1)
ax2 = uf.linearticks(ax2, ymajorsep=5, yminorsep=1)

ax.set_ylabel('Absorbance (OD)', fontsize=fs)
ax2.set_ylabel(r'PL (counts/10$^4$)', fontsize=fs)
ax.set_xlabel('Wavelength (nm)', fontsize=fs)

ax.legend(frameon=False, fontsize=fs, borderpad=0, loc='upper left', handlelength=1.3, handletextpad=0.4)
ax2.legend(frameon=False, fontsize=fs, borderpad=0, loc='upper right', handlelength=1.3, handletextpad=0.4)

fig.subplots_adjust(left=.16, bottom=.2, right=.84, top=.97)
fig.set_size_inches(single_col_width, single_col_width*0.65)
fig.savefig(os.path.join('fig1x.{0}'.format(fmt)), format=fmt, dpi=dpi)#, bbox_inches='tight')