import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


# load the simulation results
N0_psTA = [1.8, 4.2, 9.6]
psTA_rub = {}
for N0 in N0_psTA:
    psTA_rub[N0] = pd.read_csv(os.path.join('data', 'Rub_psTA_{0}E17percm3.csv'.format(N0)), header=0, index_col=0)

# load the data
kn = {}
df = pd.read_csv(os.path.join('data', 'Rub_NP_1_TA_dynamics.csv'), header=0, index_col=0)
kn[0] = df
df = pd.read_csv(os.path.join('data', 'Rub_NP_2_TA_dynamics.csv'), header=0, index_col=0)
kn[1] = df
df = pd.read_csv(os.path.join('data', 'Rub_NP_3_TA_dynamics.csv'), header=0, index_col=0)
kn[2] = df

alphas = [0.1, 0.3, 0.5]
alphas1 = [0.333, 0.667, 1]

fig, ax = plt.subplots()

ax.axhline(0, linewidth=1, color='0.5')   

for i, N0 in enumerate(N0_psTA):
    
    sim = psTA_rub[N0]
    data = kn[i]
    
    normf = data['S'].max()
    
    ax.plot(data.index, data['S']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_rubrene)
    ax.plot(sim.index, sim['S'], color=colour_rubrene, alpha=alphas1[i], linewidth=lw, label=r'{0:.1f}$\times$10$^{{17}}$cm$^{{-3}}$'.format(N0))

    ax.plot(data.index, data['T']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_triplet)
    ax.plot(sim.index, sim['T'], color=colour_triplet, alpha=alphas1[i], linewidth=lw)

ax.text(0.15, 0.2, 'triplet', color=colour_triplet, fontsize=fs, transform=ax.transAxes)
ax.text(0.3, 0.85, 'singlet', color=colour_rubrene, fontsize=fs, transform=ax.transAxes)

ax.legend(frameon=False, loc='upper right', borderpad=0, fontsize=fs, handletextpad=0.5, handlelength=1, labelspacing=0.12)
   
ax.set_xlim([0.1, 7000])

ax.set_xscale('log')

ax.set_ylabel(r'$\Delta$A (norm.)', fontsize=fs)
ax.set_xlabel('Time (ps)', fontsize=fs)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

ax = uf.linearticks(ax, ymajorsep=0.2, yminorsep=0.1)
ax = uf.logticks(ax, which='x')

fig.subplots_adjust(left=.16, bottom=.18, right=.97, top=.97)
fig.set_size_inches(single_col_width, single_col_width*0.8)
fig.savefig(os.path.join('fig4x.{0}'.format(fmt)), format=fmt, dpi=dpi)#, bbox_inches='tight')