import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf


rub_mcr = pd.read_csv(os.path.join('data', 'Rub_MCRALS.csv'), header=0, index_col=0)


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


fig, axes = plt.subplots(nrows=1, ncols=2, gridspec_kw={'wspace': 0.4})
x = np.linspace(0, 100, 1000)


# SINGLET DECAY
###############################################################################
ax = axes[0]

ax.plot(rub_mcr.index, 1000*rub_mcr['S'], marker='o', linestyle='None', ms=ms)
ax.set_xlim(-2, 30)
ax.set_ylim(0, 25)
ax.set_xlabel('Time (ps)', fontsize=fs)
ax.set_ylabel(r'$\Delta$A (mOD)', fontsize=fs)

ax.plot(x, 10+12*np.exp(-x/5), 'k-', linewidth=lw)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=10, xminorsep=2, ymajorsep=5, yminorsep=1)

ax.text(6, 6, r'$\tau=5$ps', fontsize=fs)

ax.set_title('MCR-ALS singlet decay', fontsize=fs)

# TRIPLET RISE
###############################################################################
ax = axes[1]

ax.plot(rub_mcr.index, 1000*rub_mcr['T'], marker='o', linestyle='None', ms=ms)
ax.set_xlim(-2, 30)
ax.set_ylim(0, 4.5)
ax.set_xlabel('Time (ps)', fontsize=fs)
ax.set_ylabel(r'$\Delta$A (mOD)', fontsize=fs)

ax.plot(x, 3.5*(1-np.exp(-x/5)), 'k-', linewidth=lw)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=10, xminorsep=2, ymajorsep=1, yminorsep=0.5)

ax.text(6, 1, r'$\tau=5$ps', fontsize=fs)

ax.set_title('MCR-ALS triplet rise', fontsize=fs)

fig.subplots_adjust(left=.18, bottom=.2, right=.85, top=.90)
fig.set_size_inches(double_col_width, double_col_width*0.35)
fig.savefig(os.path.join('figS1x.{0}'.format(fmt)), format=fmt, dpi=dpi)#, bbox_inches='tight')