import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
from matplotlib.legend_handler import HandlerTuple
import matplotlib.gridspec as gridspec


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'



# TA
ta_np = pd.read_csv(os.path.join('data', 'Rub_NP_TA_510nm.csv'), header=0, index_col=0)
ta_film = pd.read_csv(os.path.join('data', 'Rub_film_TA_510nm.csv'), header=0, index_col=0)

# PL
pl_np = pd.read_csv(os.path.join('data', 'Rub_NP_TRPL_integrated.csv'), header=0, index_col=0, squeeze=True)
pl_film = pd.read_csv(os.path.join('data', 'Rub_film_TRPL_integrated.csv'), header=0, index_col=0, squeeze=True)

pl_comp = pd.read_csv(os.path.join('data', 'Rub_PL_compare.csv'), header=0, index_col=0)


# create the grid
fig = plt.figure()

grid = gridspec.GridSpec(1, 2, wspace=0.18, width_ratios=[2, 1])

gridl = gridspec.GridSpecFromSubplotSpec(2, 2, subplot_spec=grid[0], wspace=0.07, hspace=0.07)
gridr = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=grid[1])

# TA NP
inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=gridl[0, 0])
ax = plt.Subplot(fig, inner[0])
fig.add_subplot(ax)

alphas = [0.2, 0.4, 0.8]
for p, pulse_energy in enumerate(ta_np.columns):
    
    ta_x = ta_np[pulse_energy]
    
    normf = ta_x[(ta_x.index > 5) & (ta_x.index < 10)].mean()
    scale = 0.9
    
    ta_xp = scale*ta_x/normf
    ta_xp.index = ta_xp.index+1-ta_xp.idxmax()
    
    ax.loglog(ta_xp.index, ta_xp, color=colour_triplet, linestyle='None', marker='o', ms=ms, mew=0, alpha=alphas[p], label=pulse_energy.replace('u', r'$\mu$').replace('cm2', r'cm$^{-2}$'))
    
ax.set_xlim(1, 2e5)
ax.set_ylim(3e-3, 1.2)

ax = uf.logticks(ax, which='both')
ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

#ax.set_xlabel('Time (ns)', fontsize=fs)
ax.set_xticklabels([])
ax.set_ylabel(r'$\Delta$T/T (norm.)', fontsize=fs)

ax.legend(frameon=False, loc=(0.02, 0.02), borderpad=0, fontsize=fs, handletextpad=0, handlelength=1, labelspacing=0.08)


# PL NP
inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=gridl[1, 0])
ax = plt.Subplot(fig, inner[0])
fig.add_subplot(ax)

pl_xp = pl_np/pl_np.max()
    
ax.loglog(pl_xp.index, pl_xp, color=colour_rubrene, linestyle='None', marker='o', ms=ms, mew=0, label=r'255$\mu$Jcm$^{-2}$')
    
ax.set_xlim(1, 2e5)
ax.set_ylim(1e-7, 2)

ax = uf.logticks(ax, which='both')
ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

ax.set_xlabel('Time (ns)', fontsize=fs)
ax.set_ylabel('PL intensity (norm.)', fontsize=fs)

for label in ax.yaxis.get_ticklabels()[1::2]:
    label.set_visible(False)

ax.legend(frameon=False, loc=(0.02, 0.02), borderpad=0, fontsize=fs, handletextpad=0, handlelength=1, labelspacing=0.08)


# TA film
cutoff = 5e3

inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=gridl[0, 1])
ax = plt.Subplot(fig, inner[0])
fig.add_subplot(ax)

alphas = [0.2, 0.4, 0.8]
for p, pulse_energy in enumerate(ta_np.columns):
    
    ta_x = ta_film[pulse_energy]
    ta_x = ta_x[ta_x.index <= cutoff]
    
    normf = ta_x[(ta_x.index > 2) & (ta_x.index < 4)].mean()
    scale = 0.9
    
    ta_xp = scale*ta_x/normf
    ta_xp.index = ta_xp.index+1-ta_xp.idxmax()
    
    ax.loglog(ta_xp.index, ta_xp, color=colour_triplet, linestyle='None', marker='o', ms=ms, mew=0, alpha=alphas[p], label=pulse_energy.replace('u', r'$\mu$').replace('cm2', r'cm$^{-2}$'))
    
ax.set_xlim(1, 2e5)
ax.set_ylim(3e-3, 1.2)

ax = uf.logticks(ax, which='both')
ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

#ax.set_xlabel('Time (ns)', fontsize=fs)
ax.set_xticklabels([])
ax.set_yticklabels([])

ax.legend(frameon=False, loc=(0.02, 0.02), borderpad=0, fontsize=fs, handletextpad=0, handlelength=1, labelspacing=0.08)


# PL film
inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=gridl[1, 1])
ax = plt.Subplot(fig, inner[0])
fig.add_subplot(ax)

pl_xp = pl_film/pl_film.max()
pl_xp = pl_xp[pl_xp.index <= cutoff]
    
ax.loglog(pl_xp.index, pl_xp, color=colour_rubrene, linestyle='None', marker='o', ms=ms, mew=0, label=r'255$\mu$Jcm$^{-2}$')
    
ax.set_xlim(1, 2e5)
ax.set_ylim(1e-7, 2)

ax = uf.logticks(ax, which='both')
ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

ax.set_xlabel('Time (ns)', fontsize=fs)
ax.set_yticklabels([])

for label in ax.yaxis.get_ticklabels()[1::2]:
    label.set_visible(False)

ax.legend(frameon=False, loc=(0.02, 0.02), borderpad=0, fontsize=fs, handletextpad=0, handlelength=1, labelspacing=0.08)


# PL compare
inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=gridr[0])
ax = plt.Subplot(fig, inner[0])
fig.add_subplot(ax)
    
ax.plot(pl_comp.index, pl_comp['RUB_NP']/(10000*0.9), color=colour_rubrene, linewidth=lw, label='NP')
ax.plot(pl_comp.index, pl_comp['RUB_film']/(10000*0.27), color='k', linewidth=lw, label='film')
    
ax.set_xlim(525, 725)
ax.set_ylim(0, 9)

ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10)
ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

ax.set_xlabel('Wavelength (nm)', fontsize=fs)
ax.set_ylabel(r'PL intensity (counts/10$^{4}$)')

for label in ax.yaxis.get_ticklabels()[1::2]:
    label.set_visible(False)

ax.legend(frameon=False, loc='upper right', borderpad=0, fontsize=fs, handletextpad=0.5, handlelength=1, labelspacing=0.08)
   
fig.subplots_adjust(left=.09, bottom=.18, right=.98, top=.96)
fig.set_size_inches(double_col_width, double_col_width*0.4)
fig.savefig(os.path.join('figS10x.{0}'.format(fmt)), format=fmt, dpi=dpi)