import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf
import matplotlib.gridspec as gridspec


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


# load the simulation results
N0_psTA = [1.2, 4.2, 9.6]
psTA_rubDBP = {}
psTA_rubDBP_2 = {}
for N0 in N0_psTA:
    psTA_rubDBP[N0] = pd.read_csv(os.path.join('data', 'RubDBP_psTA_{0}E17percm3.csv'.format(N0)), header=0, index_col=0)
    psTA_rubDBP_2[N0] = pd.read_csv(os.path.join('data', 'RubDBP_2_psTA_{0}E17percm3.csv'.format(N0)), header=0, index_col=0)

# load the data
kn = {}
df = pd.read_csv(os.path.join('data', 'RubDBP_NP_1_TA_dynamics.csv'), header=0, index_col=0)
kn[0] = df
df = pd.read_csv(os.path.join('data', 'RubDBP_NP_2_TA_dynamics.csv'), header=0, index_col=0)
kn[1] = df
df = pd.read_csv(os.path.join('data', 'RubDBP_NP_3_TA_dynamics.csv'), header=0, index_col=0)
kn[2] = df

alphas = [0.1, 0.3, 0.5]
alphas1 = [0.333, 0.667, 1]

fig = plt.figure()
grid = gridspec.GridSpec(1, 2, wspace=0.07, width_ratios=[1, 1])

###############################################################################

inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=grid[0])
ax1 = plt.Subplot(fig, inner[0])
fig.add_subplot(ax1)

ax1.axhline(0, linewidth=1, color='0.5')   

for i, N0 in enumerate(N0_psTA):
    
    sim = psTA_rubDBP[N0]
    data = kn[i]
    
    normf = data['S'].max()
        
    ax1.plot(data.index, data['S']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_rubrene)
    ax1.plot(sim.index, sim['S'], color=colour_rubrene, alpha=alphas1[i], linewidth=lw, label=r'{0:.1f}$\times$10$^{{17}}$cm$^{{-3}}$'.format(N0))

    ax1.plot(data.index, data['T']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_triplet)
    ax1.plot(sim.index, sim['T'], color=colour_triplet, alpha=alphas1[i], linewidth=lw)
        
    ax1.plot(data.index, data['C']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_dbp)
    ax1.plot(sim.index, sim['C'], color=colour_dbp, alpha=alphas1[i], linewidth=lw)

ax1.set_ylim([-0.1, 1.1])

ax1.text(0.85, 0.56, 'DBP', color=colour_dbp, fontsize=fs, transform=ax1.transAxes)
ax1.text(0.4, 0.115, 'triplet', color=colour_triplet, fontsize=fs, transform=ax1.transAxes)
ax1.text(0.2, 0.9, 'singlet', color=colour_rubrene, fontsize=fs, transform=ax1.transAxes)

ax1.legend(frameon=False, loc='upper right', borderpad=0, fontsize=fs, handletextpad=0.5, handlelength=1, labelspacing=0.12)
   
ax1.set_xlim([0.1, 7000])
ax1.set_xscale('log')

ax1.set_ylabel(r'$\Delta$A (norm.)', fontsize=fs)
ax1.set_xlabel('Time (ps)', fontsize=fs)

ax1 = uf.format_axes(ax1, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

ax1 = uf.linearticks(ax1, ymajorsep=0.2, yminorsep=0.1)
ax1 = uf.logticks(ax1, which='x')

###############################################################################

inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=grid[1])
ax1 = plt.Subplot(fig, inner[0])
fig.add_subplot(ax1)

ax1.axhline(0, linewidth=1, color='0.5')   

for i, N0 in enumerate(N0_psTA):
    
    sim = psTA_rubDBP_2[N0]
    data = kn[i]
    
    normf = data['S'].max()
        
    ax1.plot(data.index, data['S']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_rubrene)
    ax1.plot(sim.index, sim['S'], color=colour_rubrene, alpha=alphas1[i], linewidth=lw, label=r'{0:.1f}$\times$10$^{{17}}$cm$^{{-3}}$'.format(N0))

    ax1.plot(data.index, data['T']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_triplet)
    ax1.plot(sim.index, sim['T'], color=colour_triplet, alpha=alphas1[i], linewidth=lw)
        
    ax1.plot(data.index, data['C']/normf, marker='o', ms=ms, mew=0, alpha=alphas[i], linestyle='None', color=colour_dbp)
    ax1.plot(sim.index, sim['C'], color=colour_dbp, alpha=alphas1[i], linewidth=lw)

ax1.set_ylim([-0.1, 1.1])

ax1.text(0.85, 0.56, 'DBP', color=colour_dbp, fontsize=fs, transform=ax1.transAxes)
ax1.text(0.4, 0.115, 'triplet', color=colour_triplet, fontsize=fs, transform=ax1.transAxes)
ax1.text(0.2, 0.9, 'singlet', color=colour_rubrene, fontsize=fs, transform=ax1.transAxes)

ax1.legend(frameon=False, loc='upper right', borderpad=0, fontsize=fs, handletextpad=0.5, handlelength=1, labelspacing=0.12)
   
ax1.set_xlim([.1, 7000])

ax1.set_xscale('log')

ax1.set_yticklabels([])
ax1.set_xlabel('Time (ps)', fontsize=fs)

ax1 = uf.format_axes(ax1, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

ax1 = uf.linearticks(ax1, xmajorsep=5, xminorsep=1, ymajorsep=0.2, yminorsep=0.1)
ax1 = uf.logticks(ax1, which='x')


fig.subplots_adjust(left=.18, bottom=.22, right=.85, top=.98)
fig.set_size_inches(double_col_width, double_col_width*0.35)
fig.savefig(os.path.join('figS13x.{0}'.format(fmt)), format=fmt, dpi=dpi)