import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf
import matplotlib.gridspec as gridspec


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 600
fmt = 'png'


# load the simulation results
N0_psTA = [1.2, 4.2, 9.6]
psTA_rubDBP = {}
psTA_rubDBP_2 = {}
for N0 in N0_psTA:
    psTA_rubDBP[N0] = pd.read_csv(os.path.join('data', 'RubDBP_psTA_{0}E17percm3.csv'.format(N0)), header=0, index_col=0)
    psTA_rubDBP_2[N0] = pd.read_csv(os.path.join('data', 'RubDBP_2_psTA_{0}E17percm3.csv'.format(N0)), header=0, index_col=0)

# load the data
kn = {}
df = pd.read_csv(os.path.join('data', 'RubDBP_NP_1_TA_dynamics.csv'), header=0, index_col=0)
kn[0] = df
df = pd.read_csv(os.path.join('data', 'RubDBP_NP_2_TA_dynamics.csv'), header=0, index_col=0)
kn[1] = df
df = pd.read_csv(os.path.join('data', 'RubDBP_NP_3_TA_dynamics.csv'), header=0, index_col=0)
kn[2] = df

alphas = [0.1, 0.3, 0.5]
alphas1 = [0.333, 0.667, 1]

fig = plt.figure()

grid = gridspec.GridSpec(9, 2, hspace=0.15)


# sim 1
count = 0
for i, N0 in enumerate(N0_psTA):
    
    for sp in ['S', 'T', 'C']:
    
        inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=grid[count, 0])
        ax1 = plt.Subplot(fig, inner[0])
        fig.add_subplot(ax1)
    
        sim = psTA_rubDBP[N0]
        data = kn[i]
    
        normf = data['S'].max()
    
        res = (data[sp].values/normf)-uf.resample(sim.index.values, sim[sp].values, data.index.values)
        
        
        ax1.axhline(0, linewidth=1, color='0.5')   
            
        ax1.plot(data.index, res, marker='o', ms=ms, mew=0, linestyle='None', color='k')

        ax1.set_xlim([0.1, 7000])
        
        lim = 0.5 if sp == 'C' else 0.22
        
        ax1.set_ylim(-lim, lim)
        
        ax1.set_xscale('log')
        
        if count == 8:
            ax1.set_xlabel('Time (ps)', fontsize=fs)
        else:
            ax1.set_xticklabels([])
        if count == 5:
            ax1.set_ylabel(r'Residual', fontsize=fs)
        
        ax1 = uf.format_axes(ax1, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
        
        ax1 = uf.logticks(ax1, which='x')
        
        if count in [0, 1, 3, 4]:
            ax1.text(0.98, 0.05, r'{1}: {0:.1f}$\times$10$^{{17}}$cm$^{{-3}}$'.format(N0, sp), fontsize=fs, transform=ax1.transAxes, ha='right', va='bottom')
        else:
            ax1.text(0.98, 0.95, r'{1}: {0:.1f}$\times$10$^{{17}}$cm$^{{-3}}$'.format(N0, sp), fontsize=fs, transform=ax1.transAxes, ha='right', va='top')
        
        count += 1
        
        
# sim 2
count = 0
for i, N0 in enumerate(N0_psTA):
    
    for sp in ['S', 'T', 'C']:
    
        inner = gridspec.GridSpecFromSubplotSpec(1, 1, subplot_spec=grid[count, 1])
        ax1 = plt.Subplot(fig, inner[0])
        fig.add_subplot(ax1)
    
        sim = psTA_rubDBP_2[N0]
        data = kn[i]
    
        normf = data['S'].max()
    
        res = (data[sp].values/normf)-uf.resample(sim.index.values, sim[sp].values, data.index.values)
        
        
        ax1.axhline(0, linewidth=1, color='0.5')   
            
        ax1.plot(data.index, res, marker='o', ms=ms, mew=0, linestyle='None', color='k')

        ax1.set_xlim([.1, 7000])
        
        lim = 0.5 if sp == 'C' else 0.11
        
        ax1.set_ylim(-lim, lim)
        
        ax1.set_xscale('log')
        
        if count == 8:
            ax1.set_xlabel('Time (ps)', fontsize=fs)
        else:
            ax1.set_xticklabels([])
        if count == 5:
            ax1.set_ylabel(r'Residual', fontsize=fs)
        
        ax1 = uf.format_axes(ax1, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

        ax1 = uf.logticks(ax1, which='x')
        
        if count in [0, 1, 3, 4]:
            ax1.text(0.98, 0.05, r'{1}: {0:.1f}$\times$10$^{{17}}$cm$^{{-3}}$'.format(N0, sp), fontsize=fs, transform=ax1.transAxes, ha='right', va='bottom')
        else:
            ax1.text(0.98, 0.95, r'{1}: {0:.1f}$\times$10$^{{17}}$cm$^{{-3}}$'.format(N0, sp), fontsize=fs, transform=ax1.transAxes, ha='right', va='top')
        
        count += 1

fig.subplots_adjust(left=.1, bottom=.07, right=.97, top=.97)
fig.set_size_inches(double_col_width, double_col_width*0.7*(3/2))
fig.savefig(os.path.join('figS14.{0}'.format(fmt)), format=fmt, dpi=dpi)