import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
import usefulfunctions as uf


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.coolwarm
ms = 3
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


# data
spectra_rc = pd.read_csv(os.path.join('data', 'RubDBP_Tdep_PL.csv'), header=0, index_col=0)
spectra_r = pd.read_csv(os.path.join('data', 'Rub_Tdep_PL.csv'), header=0, index_col=0)

fig, axes = plt.subplots(nrows=1, ncols=2, gridspec_kw={'wspace': 0.28})

ax = axes[0]

for i, temp in enumerate(spectra_r.columns):
    ax.plot(spectra_r.index, spectra_r[temp]/10000, color=cmap(int(256*i/len(spectra_r.columns))), label=temp, linewidth=lw)
    
ax.set_xlabel('Wavelength (nm)', fontsize=fs)
ax.set_ylabel(r'PL intensity (counts/10$^4$)', fontsize=fs)

ax.set_xlim(500, 750)
ax.set_ylim(0, 15)

ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=2, yminorsep=1)
ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

axins = inset_axes(ax, width='5%', height='50%', loc='upper right', borderpad=0.9)
gradient = np.linspace(0, 1, 256)
gradient = np.transpose(np.vstack((gradient, gradient)))
axins.imshow(gradient, cmap=cmap, aspect='auto')
axins.set_xticks([])
axins.yaxis.tick_left()
axins.set_yticks([0, 127, 255])
axins.set_yticklabels(['80K', '185K', '293K'])
axins = uf.format_axes(axins, labelsize=fs, linewidth=ax_lw, length=ax_tickl)




ax = axes[1]

for i, temp in enumerate(spectra_rc.columns):
    ax.plot(spectra_rc.index, spectra_rc[temp]/10000, color=cmap(int(256*i/len(spectra_rc.columns))), label=temp, linewidth=lw)
    
ax.set_xlabel('Wavelength (nm)', fontsize=fs)
ax.set_ylabel(r'PL intensity (counts/10$^4$)', fontsize=fs)

ax.set_xlim(500, 750)
ax.set_ylim(0, 20)

ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=5, yminorsep=1)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

axins = inset_axes(ax, width='5%', height='50%', loc='upper left', borderpad=0.9)
gradient = np.linspace(0, 1, 256)
gradient = np.transpose(np.vstack((gradient, gradient)))
axins.imshow(gradient, cmap=cmap, aspect='auto')
axins.set_xticks([])
axins.yaxis.tick_right()
axins.set_yticks([0, 127, 255])
axins.set_yticklabels(['77K', '185K', '295.7K'])
axins = uf.format_axes(axins, labelsize=fs, linewidth=ax_lw, length=ax_tickl)





fig.subplots_adjust(left=.18, bottom=.22, right=.85, top=.98)
fig.set_size_inches(double_col_width, double_col_width*0.3)
fig.savefig(os.path.join('figS15x.{0}'.format(fmt)), format=fmt, dpi=dpi)#, bbox_inches='tight')