import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 600
fmt = 'pdf'


rub_pl = pd.read_csv(os.path.join('data', 'rubPL.csv'), header=None, index_col=0, squeeze=True)
rub_pl /= rub_pl.max()
rub_abs = pd.read_csv(os.path.join('data', 'rubABS.csv'), header=None, index_col=0, squeeze=True)
dbp_abs = pd.read_csv(os.path.join('data', 'dbpABS.csv'), header=None, index_col=0, squeeze=True)

#rub_abs = rub_abs[~rub_abs.index.duplicated(keep='first')]

for i, s in enumerate([rub_pl, rub_abs, dbp_abs]):
    s.sort_index(inplace=True)

x = np.linspace(500, 700, 1000)
rub_pl_spl = uf.resample(rub_pl.index.values, rub_pl.values, x, smoothing=0)
rub_abs_spl = uf.resample(rub_abs.index.values[::2], rub_abs.values[::2], x, smoothing=0)
dbp_abs_spl = uf.resample(dbp_abs.index.values[::5], dbp_abs.values[::5], x, smoothing=0)

splines = [rub_pl_spl, rub_abs_spl, dbp_abs_spl]
for i, s in enumerate([rub_pl, rub_abs, dbp_abs]):
    fig, ax = plt.subplots()
    ax.plot(s.index, s, 'ko', mfc='None')
    ax.plot(x, splines[i], 'r-')
    ax.set_xlim(min(x), max(x))

rub_dbp_overlap = np.trapz(rub_pl_spl*dbp_abs_spl*x**4, x=x)
rub_rub_overlap = np.trapz(rub_pl_spl*rub_abs_spl*x**4, x=x)

print('\nRUB -> DBP overlap: {0:.0f}'.format(rub_dbp_overlap))
print('\nRUB -> RUB overlap: {0:.0f}\n'.format(rub_rub_overlap))

print('Ratio: {0:.1f}'.format(rub_dbp_overlap/rub_rub_overlap))

scale = 173000
fig, ax = plt.subplots()
ax.plot(x, rub_abs_spl, color='darkorange', linewidth=lw, label='Rubrene absorption')
ax.plot(x, dbp_abs_spl, color='darkred', linewidth=lw, label='DBP absorption')
ax.plot(x, scale*rub_pl_spl, 'k', linewidth=lw, label='Rubrene PL')
ax2 = ax.twinx()
ax2.plot(x, rub_pl_spl, color='k', alpha=0)

ax.fill_between(x, np.minimum(scale*rub_pl_spl, dbp_abs_spl), alpha=.1, color='darkred', linewidth=0)
ax.fill_between(x, np.minimum(scale*rub_pl_spl, rub_abs_spl), alpha=.1, color='darkorange', linewidth=0)

ax.set_xlim(min(x), max(x))
ax.set_ylim(0, 190000)
ax2.set_ylim(0, 1.1)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
ax2 = uf.format_axes(ax2, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
ax = uf.linearticks(ax, xmajorsep=20, xminorsep=10)

ax.set_xlabel('Wavelength (nm)', fontsize=fs)
ax.set_ylabel(r'Molar absorption coefficient (M$^{-1}$cm$^{-1}$)', fontsize=fs)
ax2.set_ylabel('PL intensity (normalised)', fontsize=fs)

ax.legend(frameon=False, handlelength=1.2, fontsize=fs)

fig.subplots_adjust(left=.25, bottom=.18, right=.75, top=.96)
fig.set_size_inches(double_col_width, double_col_width*0.4)
fig.savefig('figS17.{0}'.format(fmt), format=fmt, dpi=dpi)