import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf

rub_ani = pd.read_csv(os.path.join('data', 'Rub_anisotropy.csv'), header=0, index_col=0)
rub_data = pd.read_csv(os.path.join('data', 'Rub_data.csv'), header=0, index_col=0)

for df in [rub_ani, rub_data]:
    df.columns = [float(x) for x in df.columns]



# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


fig, axes = plt.subplots(nrows=1, ncols=2, gridspec_kw={'wspace': 0.4})

# PEAK SHIFT
###############################################################################

ax = axes[0]

rub_data_peak = rub_data[(rub_data.index > 420) & (rub_data.index < 450)]
rub_data_peak = rub_data_peak.loc[:, (rub_data_peak.columns > 0) & (rub_data_peak.columns < 500)]
times = rub_data_peak.columns.values
peak = pd.Series(index=times, dtype=float)
waves = np.linspace(420, 450, 200)
for t in times:
    peak_t = rub_data_peak.loc[:, t]
    peak_r = uf.resample(peak_t.index.values, peak_t.values, waves)
    peak_wl_idx = np.argmax(peak_r)
    peak_wl = waves[peak_wl_idx]
    #peak[t] = peak_wl
    peak[t] = peak_t.idxmax()

ax.plot(peak.index, peak, marker='o', linestyle='None', ms=ms)
ax.set_xlim(-10, 200)
ax.set_ylim(435, 444)
x = np.linspace(0, 200, 1000)
ax.set_xlabel('Time (ps)', fontsize=fs)
ax.set_ylabel('Wavelength (nm)', fontsize=fs)

ax.plot(x, 435.3+6.4*(1-np.exp(-x/4)), 'k-', linewidth=lw)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=2, yminorsep=1)

ax.text(20, 438, r'$\tau=4$ps', fontsize=fs)

ax.set_title('Singlet ESA peak shift', fontsize=fs)


# ANISOTROPY
###############################################################################

ax = axes[1]

wls = [440, 510, 650]

for wl in wls:
    ani = rub_ani[(rub_ani.index > wl-1) & (rub_ani.index < wl+1)].mean()
    ax.plot(ani.index, ani, marker='o', linestyle='None', label='{0}nm'.format(wl), ms=ms)
ax.set_xlim(0.1, 5000)
ax.set_xscale('log')
ax.set_ylim(-0.2, 0.2)
ax.legend(frameon=False, fontsize=fs, handletextpad=0.2)
ax.set_xlabel('Time (ps)', fontsize=fs)
ax.set_ylabel('Anisotropy', fontsize=fs)

x = np.geomspace(0.1, 5000, 1000)

ax.plot(x, -0.1+0.16*(1-np.exp(-x/1)), 'k-', linewidth=lw)
ax.plot(x, -0.18+0.21*(1-np.exp(-x/1)), 'k-', linewidth=lw)
ax.plot(x, 0.08+0.08*(np.exp(-x/1)), 'k-', linewidth=lw)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw)
ax = uf.linearticks(ax, ymajorsep=0.1, yminorsep=0.05)

ax.text(2, -0.1, r'$\tau=1$ps', fontsize=fs)

ax.set_title('Anisotropy time dependence', fontsize=fs)

fig.subplots_adjust(left=.18, bottom=.2, right=.85, top=.90)
fig.set_size_inches(double_col_width, double_col_width*0.35)
fig.savefig(os.path.join('figS2x.{0}'.format(fmt)), format=fmt, dpi=dpi)#, bbox_inches='tight')