import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
from matplotlib.legend_handler import HandlerTuple
import matplotlib.gridspec as gridspec


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.viridis
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 600
fmt = 'png'

def timeslice(df, t, dt):
    return df.loc[:, (df.columns > t-dt) & (df.columns < t+dt)].mean(axis=1)



# TA data
ids = ['NP_3']
ta, kn, sp = {}, {}, {}
for idx in ids:
    
    df = pd.read_csv(os.path.join('data', 'Rub_{0}_TA_data.csv'.format(idx)), header=0, index_col=0)
    df.columns = [float(x) for x in df.columns]
    ta[idx] = df



fig, ax = plt.subplots()
times = np.geomspace(1, 20, 20)

df = ta['NP_3']

ax.axhline(0, linewidth=lw, color='0.5')

for i, time in enumerate(times):
    colour = cmap(int(i*256/(len(times)-1)))
    
    ax.plot(df.index, 1000*timeslice(df, time, 0.2*time), color=colour, linewidth=lw, label='{0}ps'.format(time))

    ax.set_xlim(400, 660)
    #ax.set_ylim(-3, 3)

    ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
    ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10)#, ymajorsep=0.1, yminorsep=0.05)

    ax.set_xlabel('Wavelength (nm)', fontsize=fs)
    ax.set_ylabel(r'$\Delta$A (mOD)', fontsize=fs)
    
ax.axvline(477, linewidth=lw, color='0.5')

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=10, yminorsep=5)

fig.subplots_adjust(left=.32, bottom=.2, right=.7, top=.96)
fig.set_size_inches(double_col_width, double_col_width*0.37)
fig.savefig(os.path.join('figS3.{0}'.format(fmt)), format=fmt, dpi=dpi)
    

