import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf


data = pd.read_csv(os.path.join('data', 'TCSPC.csv'), header=0, index_col=0)


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


fig, axes = plt.subplots(nrows=1, ncols=2, gridspec_kw={'wspace': 0.4})
x = np.linspace(0, 100, 1000)


# RUB
###############################################################################
ax = axes[0]

ax.plot(data.index, data['Rub Sheffield SUM'], linewidth=lw, label=r'18 months; $\Phi$ ~ 3%')
ax.plot(data.index, data['Rub 3months SUM'], linewidth=lw, label=r'3 months; $\Phi$ ~ 7%')

ax.set_yscale('log')

ax.set_xlim(0, 200)
ax.set_ylim(1, 2e4)
ax.set_xlabel('Time (ps)', fontsize=fs)
ax.set_ylabel('PL intensity (counts)', fontsize=fs)



ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10)
ax = uf.logticks(ax, which='y')

ax.set_title('Rubrene NPs', fontsize=fs)

ax.legend(frameon=False, fontsize=fs-1.5, handlelength=1.3, borderpad=0, loc='upper right')



# RUB/DBP
###############################################################################
ax = axes[1]

ax.plot(data.index, data['RubDBP Sheffield 590nm'], linewidth=lw, label=r'18 months; 590nm; $\Phi$ ~ 46%')
ax.plot(data.index, data['RubDBP Sample4 590nm'], linewidth=lw, label=r'<1 month; 590nm; $\Phi$ = 61%')
ax.plot(data.index, data['RubDBP Sheffield 640nm'], linewidth=lw, label=r'18 months; 640nm; $\Phi$ ~ 46%')
ax.plot(data.index, data['RubDBP Sample4 640nm'], linewidth=lw, label=r'<1 month; 640nm; $\Phi$ = 61%')

ax.set_yscale('log')

ax.set_xlim(0, 200)
ax.set_ylim(1, 2e4)
ax.set_xlabel('Time (ps)', fontsize=fs)
ax.set_ylabel('PL intensity (counts)', fontsize=fs)



ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10)
ax = uf.logticks(ax, which='y')

ax.set_title('Rubrene/DBP NPs', fontsize=fs)

ax.legend(frameon=False, fontsize=fs-1.5, handlelength=1.3, borderpad=0, loc='upper right')


fig.subplots_adjust(left=.18, bottom=.2, right=.85, top=.90)
fig.set_size_inches(double_col_width, double_col_width*0.35)
fig.savefig(os.path.join('figS5x.{0}'.format(fmt)), format=fmt, dpi=dpi)#, bbox_inches='tight')