import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf
from tripletpairs.toolkit import convolve_irf
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
import matplotlib.gridspec as gridspec


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 2.5
cs = 2.5
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 600
fmt = 'png'


gammas = [9e-22, 5e-22, 3.5e-22]
kT = 1e-5
T01 = 1e16

cuton = 100

def bimolecular_annihilation(t, T0, kT, gamma):
    return np.exp(-kT*t)/(1+(gamma*T0/kT)*(1-np.exp(-kT*t)))


# TA
ta = pd.read_csv(os.path.join('data', 'Rub_TA_510nm.csv'), header=0, index_col=0)

fig, ax = plt.subplots()

conv = 2.3e16*0.4*2

alphas = [0.2, 0.4, 0.8]
for p, pulse_energy in enumerate(ta.columns):
    
    ta_x = ta[pulse_energy]
    
    normf = ta_x[(ta_x.index > 5) & (ta_x.index < 10)].mean()
    #scale = 0.9
    
    #ta_xp = scale*ta_x/normf
    
    
    T0 = conv*float(pulse_energy.replace('uJcm2', ''))
    
    #T0 = T01*float(pulse_energy.replace('uJcm2', ''))/5
    
    ta_xp = T0*ta_x/normf
    
    ax.plot(np.exp(ta_xp.index*kT), 1e17/ta_xp, color=colour_triplet, linestyle='None', marker='o', ms=ms, mew=0, alpha=alphas[p])
    
    #T0 = conv*float(pulse_energy.replace('uJcm2', ''))
    #model = bimolecular_annihilation(ta_xp.index, T0, kT, gamma*1e-9)
    #ax.loglog(ta_xp.index, mscale*model, 'r-', linewidth=lw, alpha=alphas[p])
    
    x = np.exp(ta_xp.index*kT)
    gamma = gammas[p]
    ax.plot(x, 1e17*(((1/T0)+gamma/kT)*x-(gamma/kT)), 'r-', linewidth=lw, alpha=alphas[p], label=r'$\gamma$={0:.2f}$\times$10$^{{-12}}$cm$^3$s$^{{-1}}$'.format(gamma*1e21))
    
ax.set_xlim(1, 2)
ax.set_ylim(0, 12)

ax.legend(frameon=False, loc='upper left', borderpad=0, fontsize=fs, handletextpad=0.5, handlelength=1, labelspacing=0.08) 

#ax = uf.logticks(ax, which='both')
ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)

ax.set_ylabel(r'1 / T(t) (cm$^3\times$10$^{-17}$)', fontsize=fs)
ax.set_xlabel(r'exp(k$_T$t)', fontsize=fs)

#ax.legend(frameon=False, loc=(0.02, 0.02), borderpad=0, fontsize=fs, handletextpad=0, handlelength=1, labelspacing=0.08) 
    
    
fig.subplots_adjust(left=.37, bottom=.22, right=.65, top=.96)
fig.set_size_inches(double_col_width, double_col_width*0.3)
fig.savefig(os.path.join('figS6.{0}'.format(fmt)), format=fmt, dpi=dpi)