import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import usefulfunctions as uf


# plotting parameters
plt.rc('font', family='serif', serif='Arial')
single_col_width = 3.26772
double_col_width = 6.73228
fs = 8
lw = 1
ax_lw = 0.8
ax_tickl = 4
cut = 10
cmap = plt.cm.RdBu_r
ms = 4
cbar_ax_colour = 'k'
colour_rubrene = 'darkorange'
colour_dbp = 'darkred'
colour_triplet = 'darkblue'
dpi = 300
fmt = 'svg'


# absorption
solid_abs = pd.read_csv(os.path.join('data', 'Rub_film.csv'), header=0, index_col=0, squeeze=True)


fig, ax = plt.subplots(figsize=(0.8*0.47*14, 4))
#fig, ax = plt.subplots()

ax.plot(solid_abs.index, solid_abs, linewidth=lw, color='k', linestyle='-', label='film')


ax.set_ylim(0, 0.15)
ax.set_xlim(360, 750)

ax = uf.format_axes(ax, labelsize=fs, linewidth=ax_lw, length=ax_tickl)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=0.05, yminorsep=0.01)

ax.set_ylabel('Absorbance (OD)', fontsize=fs)
ax.set_xlabel('Wavelength (nm)', fontsize=fs)


fig.subplots_adjust(left=.16, bottom=.2, right=.84, top=.97)
fig.set_size_inches(single_col_width, single_col_width*0.65)
fig.savefig(os.path.join('figS9x.{0}'.format(fmt)), format=fmt, dpi=dpi)#, bbox_inches='tight')