# Data and Figures #
This document is intended to act as a guide to the contents of this data package. A folder is provided for each figure in both the main article and supplementary information. Within each folder is a `data` folder containing all the data displayed in that figure. Also included is the python script used to generate the parts of the figure containing numerical data.

Please note that where figures contained data republished with permission from a third-party (Figure 2), this data has been removed from both the `data` folder and the figure files included in this repository.

For information regarding experimental protocols and data analysis methods, please refer to the methods section and supplementary information for the publication.

## Contents ##
* [Index](#index)
    - [Main Article](#main-article)
      * [Figure 1](#figure-1)
      * [Figure 2](#figure-2)
      * [Figure 3](#figure-3)
      * [Figure 4](#figure-4)
      * [Figure 5](#figure-5)
      * [Figure 6](#figure-6)
    - [Supplementary Information](#supplementary-information)
      * [Figure S1](#figure-s1)
      * [Figure S2](#figure-s2)
      * [Figure S3](#figure-s3)
      * [Figure S4](#figure-s4)
      * [Figure S5](#figure-s5)
      * [Figure S6](#figure-s6)
      * [Figure S7](#figure-s7)
      * [Figure S8](#figure-s8)
      * [Figure S9](#figure-s9)
      * [Figure S10](#figure-s10)
      * [Figure S11](#figure-s11)
      * [Figure S12](#figure-s12)
      * [Figure S13](#figure-s13)
      * [Figure S14](#figure-s14)
      * [Figure S15](#figure-s15)
      * [Figure S16](#figure-s16)
      * [Figure S17](#figure-s17)
* [Figure Generation](#figure-generation)
* [Analysis and Simulation Code](#analysis-and-simulation-code)

## Index ##
Within each `data` folder are a series of `.csv` files containing numerical data. The index below indicates what data is included in each file and where it appears on the final figure.

#### Main Article ####

##### Figure 1 #####
_Rubrene absorption and emission spectra_
- **Rub_NP_PL.csv** is the steady-state PL spectrum of the rubrene nanoparticle film (orange line)
- **Rub_solid_abs.csv** is the ground state absorption spectrum of the rubrene nanoparticle film (solid black line)
- **Rub_solution_abs.csv** is the ground state absorption spectrum of rubrene monomers in dilute toluene solution (dashed grey line)
- **RubDBP_NP_PL.csv** is the steady-state PL spectrum of the DBP-doped rubrene nanoparticle film (red line)

##### Figure 2 #####
_Rubrene transient absorption_
- **Rub_XX_TA_YY.csv** contain the TA data for the nanoparticle film (XX=NP_i, where i=1,2,3 corresponds to excitation densities of 8, 18 and 41 &#956;Jcm<sup>-2</sup>), dilute solution (XX=solution) and polycrystalline film (XX=film). YY refers to the type of data in the file: YY=data refers to the full wavelength vs time matrix (41&#956;Jcm<sup>-2</sup>), YY=spectra is the spectral components extracted by MCR-ALS and YY=dynamics contains the concentrations of those MCR-ALS components. Note that the MCR-ALS components are labelled S, T, C for rubrene singlets, rubrene triplets and DBP singlets. Obviously, DBP singlet concentrations were set to zero for pure rubrene samples.

##### Figure 3 #####
_TRPL of rubrene nanoparticle films_
- **Rub_integrated_PL.csv** contains integrated steady state PL values scaled by the PLQY values measured at both 77K and room temperature. This data was used to produce panel E.
- **Rub_MFE.csv** contains the time-gated magnetic field effect values and errors plotted in panel C.
- **Rub_TA_510nm.csv** contains the fluence dependent long-time transient absorption data at a probe wavelength of 510nm plotted in panel B.
- **Rub_TSCPC.csv** is the wavelength-integrated TCSPC decay data plotted in panel A.
- **Rub_TRPL_XX_integrated.csv** contain the fluence dependent TRPL decays measured using the iCCD camera, shown in panels A and D. XX gives the temperature at which the decays were recorded.
- **TSCPC_IRF.csv** contains the instrument response function of the TCSPC setup.

##### Figure 4 #####
_Simulation of rubrene nanoparticle film ps TA data_
- **Rub_NP_i_TA_dynamics.csv** contains the MCR-ALS concentrations of singlets and triplets. i corresponds to the fluences used (i=1,2,3 corresponding to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>).
- **Rub_psTA_XXpercm3.csv** are the corresponding simulated dynamics at the excitation density given by XX, which was estimated from the measured fluence and absorption spectrum of the rubrene nanoparticle films.

##### Figure 5 #####
_Transient absorption of rubrene/DBP nanoparticle films_
- **Rub_NP_i_TA_dynamics.csv** contains the MCR-ALS singlet and triplet dynamics of the pure rubrene nanoparticle films at i=1,2,3 corresponding to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>.
- **RubDBP_NP_i_TA_dynamics.csv** contains the MCR-ALS singlet (Rub), singlet (DBP) and triplet (Rub) dynamics of the rubrene/DBP nanoparticle films at i=1,2,3 corresponding to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>.
- **RubDBP_NP_TA_data.csv** contains the wavelength vs time TA matrix of the rubrene/DBP nanoparticle films at a fluence of 18&#956;Jcm<sup>-2</sup>.
- **RubDBP_NP_TA_spectra.csv** contains the MCR-ALS spectral components of the rubrene/DBP nanoparticle film.

##### Figure 6 #####
_TRPL of rubrene/DBP nanoparticle films_
In the filenames below XX=Rub corresponds to data for pure rubrene nanoparticle films whilst XX=RubDBP corresponds to data for rubrene/DBP nanoparticle films.
- **XX_integrated_PL.csv** contains integrated steady state PL values scaled by the PLQY values measured at both 77K and room temperature.
- **XX_MFE.csv** contains the time-gated magnetic field effect values and errors.
- **XX_NP_TRPL_integrated.csv** contain the fluence dependent TRPL decays measured using the iCCD camera.
- **XX_TA_510nm.csv** contains the fluence dependent long-time transient absorption data at a probe wavelength of 510nm.
- **XX_TSCPC.csv** is the TCSPC decay data.

#### Supplementary Information ####

##### Figure S1 #####
_Singlet fission dynamics of rubrene nanoparticle films_
- **Rub_MCRALS.csv** are the singlet and triplet (S, T) dynamics extracted via MCR-ALS for the pure rubrene nanoparticle film.

##### Figure S2 #####
_Anisotropy and peak shifts in rubrene nanoparticle films_
- **Rub_anisotropy.csv** is the wavelength vs time transient absorption anisotropy matrix for the pure rubrene nanoparticle film.
- **Rub_data.csv** is the wavelength vs time transient absorption matrix for the pure rubrene nanoparticle film. The shift in the singlet PIA peak was extracted from this data.

##### Figure S3 #####
_Isosbestic point in rubrene nanoparticle film TA data_
- **Rub_NP_3_TA_data.csv** is the wavelength vs time transient absorption matrix for the pure rubrene nanoparticle film.

##### Figure S4 #####
_Comparison of fresh and aged nanoparticle films: TA_
- **XX_NP_YY_ZZ.csv** are the wavelength vs time transient absorption matrices for the pure rubrene (XX=Rub) or rubrene/DBP (XX=RubDBP) nanoparticle film. YY=400nm or 532nm gives the excitation wavelength and ZZ=fresh or stored refers to the time between sample preparation and measurement.

##### Figure S5 #####
_Comparison of fresh and aged nanoparticle films: TCSPC_
- **TCSPC.csv** contains all the TCSPC decays plotted in the figure, labelled by their column headers.

##### Figure S6 #####
_Estimation of annihilation rate constant in rubrene nanoarpticle films_
- **Rub_TA_510nm.csv** contains the fluence dependent long-time transient absorption data probed at 510nm for a pure rubrene nanoparticle film.

##### Figure S7 #####
_TA of DBP monomers in solution_
- **DBP_solution_TA_XX.csv** are the transient absorption matrix (XX=data), spectral component averaged from 10ps onwards (XX=spectra) and dynamics at 600mn (XX=dynamics) for DBP monomers in dilute THF solution.

##### Figure S8 #####
_MCR-ALS residuals_
- **Rub_fXX.csv** are the MCR-ALS residuals matrices, normalised to the maximum TA signals, for the polycrystalline rubrene films. XX denotes the mol fraction of DBP present in the film.
- **XX_NP_i.csv** are the MCR-ALS residuals matrices, normalised to the maximum TA signals, for the pure rubrene (XX=Rub) and rubrene/DBP (XX=RubDBP) nanoparticle film. i=1,2,3 correspond to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>.

##### Figure S9 #####
_Polycrystalline rubrene film_
- **Rub_film.csv** contains the ground state absorption spectrum of the pure polycrystalline rubrene film sample.

##### Figure S10 #####
_Comparison of rubrene nanoparticle and polycrystalline film PL_
- **Rub_film_TA_510nm.csv** contains the fluence dependent long-time transient absorption data probed at 510nm for the rubrene polycrystalline film.
- **Rub_film_TRPL_integrated.csv** contains the fluence dependent, wavelength integrated TRPL data for the polycrystalline film, measured using the iCCD.
- **Rub_NP_TA_510nm.csv** contains the fluence dependent long-time transient absorption data probed at 510nm for the rubrene nanoparticle film.
- **Rub_NP_TRPL_integrated.csv** contains the fluence dependent, wavelength integrated TRPL data for the nanoparticle film, measured using the iCCD.
- **Rub_PL_compare.csv** contains the steady-state PL spectra, in counts to enable direct comparison, of the rubrene nanoparticle film and polycrystalline film, labelled by their column headers.

##### Figure S11 #####
_Comparison of pure rubrene and rubrene/DBP polycrystalline films_
- **XX_film_TA_YY.csv** are the MCR-ALS spectra (YY=spectra) and dynamics (YY=dynamics) of pure rubrene (XX=Rub) and rubrene/DBP (XX=RubDBP) polycrystalline films extracted from the ps TA data.
- **Rub_PL_compare.csv** contains the steady-state PL spectra, in counts to enable direct comparison, of the rubrene polycrystalline film with and without the DBP dopant.

##### Figure S12 #####
_Residuals from the simulation of rubrene nanoparticle film ps TA data_
- **Rub_NP_i_TA_dynamics.csv** contains the MCR-ALS concentrations of singlets and triplets. i corresponds to the fluences used (i=1,2,3 corresponding to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>).
- **Rub_psTA_XXpercm3.csv** are the corresponding simulated dynamics at the excitation density given by XX, which was estimated from the measured fluence and absorption spectrum of the rubrene nanoparticle films.

##### Figure S13 #####
_Simulation of rubrene/DBP nanoparticle film ps TA data_
- **RubDBP_2_psTA_XXpercm3.csv** are the simulated dynamics assuming that only 50% of rubrene singlets can undergo FRET to DBP. XX gives the initial excitation density, calculated from the measured pump fluence and absorption spectrum.
- **RubDBP_NP_i_TA_dynamics.csv** are the population dynamics extracted by MCR-ALS from the TA data of the rubrene/DBP nanoparticle film. i=1,2,3 corresponds to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>.
- **RubDBP_psTA_XXpercm3.csv** are the simulated dynamics assuming that all rubrene singlets can undergo FRET to DBP. XX gives the initial excitation density, calculated from the measured pump fluence and absorption spectrum.

##### Figure S14 #####
_Residuals from the simulation of rubrene/DBP nanoparticle film ps TA data_
- **RubDBP_2_psTA_XXpercm3.csv** are the simulated dynamics assuming that only 50% of rubrene singlets can undergo FRET to DBP. XX gives the initial excitation density, calculated from the measured pump fluence and absorption spectrum.
- **RubDBP_NP_i_TA_dynamics.csv** are the population dynamics extracted by MCR-ALS from the TA data of the rubrene/DBP nanoparticle film. i=1,2,3 corresponds to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>.
- **RubDBP_psTA_XXpercm3.csv** are the simulated dynamics assuming that all rubrene singlets can undergo FRET to DBP. XX gives the initial excitation density, calculated from the measured pump fluence and absorption spectrum.

##### Figure S15 #####
_Temperature dependence of rubrene and rubrene/DBP nanoparticle film PL spectra_
- **XX_tdep_PL.csv** contain PL spectra of pure rubrene (XX=Rub) and rubrene/DBP (XX=RubDBP) PL spectra measured at the temperatures given in the column headings.

##### Figure S16 #####
_Timescales of SSA in rubrene nanoparticle film TA data_
- **Rub_NP_i_TA_dynamics.csv** contains the MCR-ALS concentrations of singlets and triplets. i corresponds to the fluences used (i=1,2,3 corresponding to fluences of 8, 18 and 41 &#956;Jcm<sup>-2</sup>).
- **Rub_psTA_XXpercm3.csv** are the corresponding simulated dynamics at the excitation density given by XX, which was estimated from the measured fluence and absorption spectrum of the rubrene nanoparticle films.

##### Figure S17 #####
_Spectral overlap for FRET rate calculations_
- **dbpABS.csv** molar extinction coefficient of DBP in solution.
- **rubABS.csv** molar extinction coefficient of rubrene in solution.
- **rubPL.csv** normalised PL spectrum of rubrene in solution.

### Figure Generation ###

Figure parts containing numerical data were produced in `.svg` format using the python plotting library [matplotlib](https://matplotlib.org/). [Inkscape](https://inkscape.org/) was then used to assemble multi-panel figures. Any microscope images and photographs were included as rasterised objects. The python scripts used to produce figure panels containing numerical data are provided in each figure folder.

You will need an installation of python 3 (I used 3.9.6) on your machine in order to run the scripts. If you do not already have one, I recommend installing [miniconda](https://docs.conda.io/en/latest/miniconda.html).

You will need the following standard packages (my versions in brackets):
 - numpy (1.20.3)
 - matplotlib (3.3.4)
 - pandas (1.3.0)

You will also need a package called usefulfunctions which you can download and install following the instructions [here](https://github.com/davidbossanyi/useful-functions).

To generate parts of a figure, run for example:
```sh
cd Figure 2
python fig2.py
```

### Analysis and Simulation Code ###
Code to perform the simulations in Figures [4](#figure-4) and [S13](#figure-s13) is available [here](https://github.com/davidbossanyi/rubrene-nanoparticle-dynamics). The python application that I used to process TRPL data taken with the iCCD camera can be found [here](https://github.com/fast-spectroscopy-sheffield/iCCD-kinetics). MCR-ALS is freely available [here](https://mcrals.wordpress.com/download/) as a MATLAB GUI.
